package Locale::CLDR::Locales::En::Any;

# This file auto generated
#	on Sun  7 Oct 10:29:33 am GMT

use version;

our $VERSION = version->declare('v0.33.1');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::En');

no Moo;

1;
